##  Side Panel for Additional Information
When you click on any sector in the radar report, a side panel opens up offering additional information about the applied view, the specific sector you clicked on, and the ring it belongs to. For example, in a tech radar report, this information could include the category and assessment of a particular technology.
Similarly, if you click on a single dot within the radar report, side panel offers details of the selected fact sheet. This allows you to quickly edit the information in the fact sheet, for example to quickly change the assessment category or perform other related actions.
![Editing Fact Sheet Fields in Side Panel of Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27444b9f7a441014b004d5dc5811c381_LowRes.gif)
Editing Fact Sheet Fields in Side Panel of Report
